@@ -3,6 +3,7 @@ import logging
 import gobject
 import gtk
 import deskbar
+import deskbar.interfaces.Match
 from deskbar.core.GconfStore import GconfStore
 from deskbar.core.ModuleInstaller import ModuleInstaller
 from deskbar.core.ModuleLoader import ModuleLoader
@@ -168,7 +169,7 @@ class CoreImpl(deskbar.interfaces.Core):
         if not self._keybinder.bind(binding):
             LOGGER.error("Keybinding is already in use")
         else:
-            LOGGER.info("Successfully binded Deskbar to %s" % binding)
+            LOGGER.info("Successfully binded Deskbar to %s", binding)
     
     def set_min_chars(self, number):
         self._gconf.set_min_chars(number)
@@ -254,7 +255,6 @@ class CoreImpl(deskbar.interfaces.Core):
         self._module_list.clear()
         self._disabled_module_list.clear()
         LOGGER.info("Reloading all modules")
-        self._module_loader.emit("modules-reloading")
         self._module_loader.load_all()
     
     def stop_queries(self):
@@ -355,6 +355,9 @@ class CoreImpl(deskbar.interfaces.Core):
             
     def forward_query_ready(self, handler, query, matches):
         if query == self._last_query and matches != None and len(matches) > 0 and not self._stop_queries:
+            for match in matches:
+                if not isinstance(match, deskbar.interfaces.Match):
+                    raise TypeError("Handler %r returned an invalid match: %r", handler,  match)
             self._emit_query_ready(matches)
     
     def update_gconf(self):
@@ -365,10 +368,11 @@ class CoreImpl(deskbar.interfaces.Core):
     def _on_default_browser_changed(self, gconfstore, new_browser):
         new_browser = new_browser.split(" ")[0]
         
-        if new_browser == "firefox":
+        if new_browser.find("firefox") != -1 or new_browser.find("iceweasel") != -1 \
+            or new_browser.find("iceweasel") != -1:
             new_browser = "mozilla"
         
-        if new_browser == "epiphany":
+        if new_browser.find("epiphany") != -1:
             old_browser = "mozilla"
         elif new_browser == "mozilla":
             old_browser = "epiphany"
@@ -386,18 +390,24 @@ class CoreImpl(deskbar.interfaces.Core):
         for module in self._module_list:
             # Check if the module is related to the old browser.
             if module.__class__.__module__ == "epiphany" or module.__class__.__module__ == "mozilla":
-                if module.is_enabled() and new_browser != "other":
-                    enabled_browser_modules.append(module.__class__.__name__)
-                self.stop_module(module, async=False)
+                if module.is_enabled(): 
+                    self.stop_module(module, async=False)
+                    if new_browser != "other":
+                        enabled_browser_modules.append(module.__class__.__name__)
+                    
                 self._module_list.remove_module(module)
+                # Refresh instructions
+                module.__class__.has_requirements ()
+                # Add module to self._disabled_module_list
                 self._module_loader.emit("module-not-initialized", module)
         
+        # Remove modules of new browser from self._disabled_module_list
         filename = None
-        for module in self._disabled_module_list:
-            if module[1].__module__ == new_browser:
+        for (icon, module, activatable) in self._disabled_module_list:
+            if module.__module__ == new_browser:
                 if filename is None:
-                    filename = module[1].filename
-                self._disabled_module_list.remove_module(module[1])
+                    filename = module.filename
+                self._disabled_module_list.remove_module(module)
                 
         if filename is not None:
             self._module_loader.load(filename)
@@ -405,7 +415,10 @@ class CoreImpl(deskbar.interfaces.Core):
         for module in enabled_browser_modules:
             new_module_name = module.replace(old_browser.capitalize(), new_browser.capitalize())
             new_module = self._module_list.get_module_instance_from_name(new_module_name)
-            # If async is True then self.update_gconf() may be run before the modules were initialized
-            self.initialize_module(new_module, async=False)
+            
+            # If new_module is None the module has missing requirements
+            if new_module != None:
+                # If async is True then self.update_gconf() may be run before the modules were initialized
+                self.initialize_module(new_module, async=False)
         
         self.update_gconf()
